# Migration to the Self-Service SSO Configuration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#overview)
  * [Important Changes](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#important-changes)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#prerequisites)
  * [Configuration Options](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#configuration-options)
  * [Migration Process](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#migration-process)
  * [Step 1: Create a New Application in Your IdP for Each Workspace](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#step-1:-create-a-new-application-in-your-idp-for-each-workspace)
  * [Step 2: Configure SSO in Your IdP](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#step-2:-configure-sso-in-your-idp)
  * [Step 3: Upload Metadata to SAP LeanIX](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration#step-3:-upload-metadata-to-sap-leanix)


View all
Migrate to the new SSO self-service for improved authentication and authorization by the end of May 2026.
